@@ -452,7 +452,7 @@ let allowed_ips = define_option current_section ["allowed_ips"]
   or 192.168.0.0-192.168.0.255 for 192.168.0.*"
     ip_range_list_option [ Ip.RangeSingleIp Ip.localhost ]
 
-let allowed_ips_set = ref Ip_set.BL_Empty
+let allowed_ips_set = ref Ip_set.bl_empty
 
 let _ =
   option_hook allowed_ips (fun _ ->
@@ -619,7 +619,7 @@ let max_indirect_connections = define_option current_section ["max_indirect_conn
     int_option 30
 
 let max_upload_slots = define_option current_section ["max_upload_slots"]
-  "How many slots can be used for upload"
+  "How many slots can be used for upload, minimum 3"
     int_option 5
 
 let max_release_slots = define_option current_section ["max_release_slots"]
@@ -1034,7 +1034,7 @@ let web_infos = define_option current_section ["web_infos"]
     (\"guarding.p2p\", 96, \"http://www.bluetack.co.uk/config/level1.gz\");
     (\"ocl\", 24, \"http://members.lycos.co.uk/appbyhp2/FlockHelpApp/contact-files/contact.ocl\");
     (\"contact.dat\", 168, \"http://download.overnet.org/contact.dat\");
-    (\"geoip.dat\", 168, \"http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz\");
+    (\"geoip.dat\", 168, \"http://www.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz\");
     ]
   "
     (list_option (tuple3_option (string_option, int_option, string_option)))
@@ -1046,7 +1046,7 @@ let web_infos = define_option current_section ["web_infos"]
       ("contact.dat", 168,
         "http://download.overnet.org/contact.dat");
       ("geoip.dat", 0,
-        "http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz");
+        "http://www.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz");
       ("nodes.gzip", 0,
         "http://update.kceasy.com/update/fasttrack/nodes.gzip");
       ("hublist", 0,
@@ -1638,7 +1638,7 @@ let max_displayed_results = define_expert_option current_section ["max_displayed
 let options_version = define_expert_option current_section ["options_version"]
   ~internal: true
   "(internal option)"
-    int_option 20
+    int_option 21
 
 let max_comments_per_file = define_expert_option current_section ["max_comments_per_file"]
   "Maximum number of comments per file"
@@ -2093,6 +2093,11 @@ let web_infos_add kind period url =
       state = None;
     }
 
+let web_infos_replace old_url new_url =
+  Hashtbl.iter (fun key w -> 
+    if w.url = old_url then w.url <- new_url
+  ) web_infos_table
+
 let _ =
 (* convert list option web_infos to a hashtable for better usage *)
   set_after_load_hook downloads_ini (fun _ ->
@@ -2219,4 +2224,10 @@ let rec update_options () =
       if !!share_scan_interval = 5 then share_scan_interval =:= 30;
       update 20
 
+  | 20 ->
+      web_infos_replace
+        "http://www.maxmind.com/download/geoip/database/GeoIP.dat.gz"
+        "http://www.maxmind.com/download/geoip/database/GeoLiteCountry/GeoIP.dat.gz";
+      update 21
+
   | _ -> ()
