@@ -585,7 +585,7 @@ let telnet_handler t event =
             conn_info = Some (TELNET, (from_ip, from_port));
           } in
 	(match Ip_set.match_ip !allowed_ips_set from_ip with
-	| Some br -> 
+	| true -> 
         TcpBufferedSocket.prevent_close sock;
         TcpBufferedSocket.set_max_output_buffer sock !!interface_buffer;
         TcpBufferedSocket.set_reader sock (user_reader o telnet);
@@ -604,7 +604,7 @@ let telnet_handler t event =
 
         after_telnet_output o sock
 
-	| None ->
+	| false ->
         before_telnet_output o sock;
 	let reject_message =
 	  Printf.sprintf "Telnet connection from %s rejected (see allowed_ips setting)\n"
@@ -816,16 +816,23 @@ let http_send_bin r buf filename =
     else
       try
         File.to_string filename
-      with _ ->
-        try
-          Hashtbl.find CommonPictures.files filename
-        with Not_found ->
-          try
-            if String.sub filename 0 4 = "flag" then
-              Hashtbl.find CommonPictures.files "flag_--.png"
-            else
-              raise Not_found
-          with _ -> raise Not_found
+      with _ -> raise Not_found
+  in
+  let ext = extension_to_file_ext (Filename2.last_extension2 filename) in
+  http_add_bin_header r ext (String.length file_to_send);
+  Buffer.add_string buf file_to_send
+
+let http_send_bin_pictures r buf filename =
+  let file_to_send =
+    try
+      Hashtbl.find CommonPictures.files filename
+    with Not_found ->
+      try
+        if String.sub filename 0 4 = "flag" then
+          Hashtbl.find CommonPictures.files "flag_--.png"
+        else
+          raise Not_found
+    with _ -> raise Not_found
   in
   let ext = extension_to_file_ext (Filename2.last_extension2 filename) in
   http_add_bin_header r ext (String.length file_to_send);
@@ -952,7 +959,7 @@ let http_handler o t r =
   let user = if r.options.login = "" then (admin_user ()).CommonTypes.user_name else r.options.login in
   if not (valid_password user r.options.passwd) || (r.get_url.Url.short_file = "logout") then begin
       clear_page buf;
-      http_file_type := HTM;
+      http_file_type := TXT;
       let _, error_text_long, header = Http_server.error_page "401" "" ""
 	(Ip.to_string (TcpBufferedSocket.my_ip r.sock))
 	(string_of_int !!http_port) None in
@@ -1501,7 +1508,7 @@ let http_handler o t r =
                 read_theme_page this_page else
               if !!html_mods then !!CommonMessages.download_html_js_mods0
               else !!CommonMessages.download_html_js_old)
-        | s ->  http_send_bin r buf (String.lowercase s)
+        | s ->  http_send_bin_pictures r buf (String.lowercase s)
       with
       | Not_found ->
 	  let _, error_text_long, header = Http_server.error_page "404" "" ""
