@@ -485,9 +485,7 @@ let is_black_address ip port cc =
   !!black_list && not (low_id ip) && (
 (* lprintf "is black ="; *)
     not (Ip.reachable ip) || 
-    (match Ip_set.match_ip !server_black_list_set ip with
-     | Some br -> true 
-     | None -> false) ||
+    (Ip_set.match_ip !server_black_list_set ip) || 
     (List.mem port !!port_black_list) ||
     (match !Ip.banned (ip, cc) with
         None -> false
